~~~~~~~~~~
References
~~~~~~~~~~

.. [Levenshtein:1966] Levenshtein VI: Binary codes capable of correcting deletions, insertions, and reversals. Soviet Physics-Doklady 1966, 10:707-710.

.. [Gusfield:1999] Gusfield D: Algorithms on strings, trees, and sequences. Cambridge, UK: Cambridge University Press; 1999:535.

.. [Hamming:1950] Hamming RW: Error detecting and error correcting codes. Bell Systems Technical Journal 1950, 29:147-160.

.. [Brownstein:1996] Brownstein MJ, Carpten JD, Smith JR: Short Technical Reports. Biotechniques 1996, 20.